5 ms·
SQLite improving performance with pre-sort
- linolevan 4mo agoNeat optimization, I've never seen that before. Thanks for sharing.
- gandreani 4mo agoIt's not clear in the code how you're batching the writes. Could the performance improvement be mostly explained by batches?
- deleted 4mo ago[deleted]
- JSR_FDED 4mo agoLooks like he’s doing 1M INSERTs per transaction. In his 2nd example he’s doing the same thing, except he first sorts the data for each of those 1M INSERTs, leading to a 2-3x speedup.
- Loranubi 4mo agoDepending on the size of the blob you might not want to use `WITHOUT ROWID`. I had a similar table with uuid keys and blobs of 40kb size on average and `WITHOUT ROWID` really tanked performance.
- Abenezer0923 4mo ago[flagged]
- rented_mule 4mo agoThis is not unique to SQLite... it should help with any database that uses B+Trees. Batch deletes are also typically faster when the IDs to be deleted are sorted in these same systems.
- yahavthehackern 4mo ago[flagged]